@@ -1,5 +1,8 @@
 from django.contrib.auth import get_user_model
 from django.core.mail import EmailMultiAlternatives
+from django.utils import timezone
+from django_slack import slack_message
+from firebase_admin.firestore import client
 from firebase_admin.messaging import Message
 from firebase_admin.messaging import Notification
 from typing import Dict
@@ -49,10 +52,14 @@ class FirebasePushChannel(BaseChannel):
     template_parts = ["title.txt", "body.txt", "data.json"]
 
     def send(self, users: List[User], context: Dict[str, str]):
-        from df_notifications.models import UserDevice
+        try:
+            devices = context["devices_queryset"]
+        except KeyError:
+            from df_notifications.models import UserDevice
 
-        devices = UserDevice.objects.filter(user__in=users)
-        devices.send_message(
+            devices = UserDevice.objects.all()
+
+        devices.filter(user__in=users).send_message(
             Message(
                 notification=Notification(
                     title=context["title.txt"],
@@ -64,8 +71,36 @@ class FirebasePushChannel(BaseChannel):
 
 
 class JSONPostWebhookChannel(BaseChannel):
-    key = "webhook"
     template_parts = ["data.json"]
 
     def send(self, users: List[User], context: Dict[str, str]):
         requests.post(context["url"], json=json.loads(context["data.json"]))
+
+
+class SlackChannel(BaseChannel):
+    template_parts = ["title.txt", "body.txt"]
+
+    def send(self, users: List[User], context: Dict[str, str]):
+        slack_message(
+            "df_notifications/base_slack.html",
+            context=context,
+            attachments=[{"text": context["body.txt"], "title": context["title.txt"]}],
+        )
+
+
+class FirebaseChatChannel(BaseChannel):
+    template_parts = ["body.txt"]
+
+    def send(self, users: List[User], context: Dict[str, str]):
+        db = client()
+        db.collection("rooms").document(context["chat_room_id"]).collection(
+            "messages"
+        ).document().set(
+            {
+                "text": context["body.txt"],
+                "createdAt": timezone.now(),
+                "updatedAt": timezone.now(),
+                "type": "text",
+                "authorId": context.get("chat_author_id", "system"),
+            }
+        )
